@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import sys, sqlite3
-from utils.DebugLog import DebugLog
+import os, sys, sqlite3
+from utils.DebugLog import DebugLog, getScriptPath
 from utils.Config import RidesConfig, ConfFile, Ride
 from utils.TrainDb import DbTrain
 from PyQt4 import QtCore, QtGui
@@ -60,7 +60,40 @@ class LineEdit(QLineEdit):
       cr = self.childrenRect()
       self.cmp.complete(cr)
 
-class AddRideDlg(QtGui.QDialog ):
+class SelectLine(QtGui.QDialog):
+   def __init__(self, lines):
+      QtGui.QDialog.__init__(self)
+      self.ligne = ''
+
+      self.setWindowTitle(u'Plusieurs lignes possible pour ce trajet')
+      iconsPath = os.path.join(os.path.dirname(getScriptPath()), 'icons')
+
+      self.lignes = QtGui.QComboBox()
+
+      for l in lines:
+         iconPath = os.path.join(iconsPath, 'tec/%dx%d/%s.png'%(32, 32, l) )
+         self.lignes.addItem(QtGui.QIcon(iconPath), l.replace('M', u'Métro ').replace('R', u'RER '))
+
+      buttons = QtGui.QDialogButtonBox()
+      buttons.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
+      self.connect(buttons, QtCore.SIGNAL("accepted()"), self.OnOK)
+      self.connect(buttons, QtCore.SIGNAL("rejected()"), self.OnCancel)
+
+      vbox = QtGui.QVBoxLayout()
+      vbox.addWidget(self.lignes)
+      vbox.addWidget(buttons)
+      self.setLayout(vbox)
+
+      self.setModal(True)
+
+   def OnOK(self):
+      self.ligne = unicode(self.lignes.currentText())
+      self.accept()
+
+   def OnCancel(self):
+      self.reject()
+
+class AddRideDlg(QtGui.QDialog):
 
    def __init__(self, garesConf):
       QtGui.QDialog.__init__(self)
@@ -102,7 +135,6 @@ class AddRideDlg(QtGui.QDialog ):
       list = QtCore.QStringList()
 
       self.db = DbTrain()
-
       c = self.db.execute('SELECT * FROM gares ORDER BY name')
 
       for row in c:
@@ -125,9 +157,9 @@ class AddRideDlg(QtGui.QDialog ):
       c.close()
 
       labelD = QtGui.QLabel()
-      labelD.setText("Depart")
+      labelD.setText(u"Départ")
       labelA= QtGui.QLabel()
-      labelA.setText(u"Arrivee")
+      labelA.setText(u"Arrivée")
 
       # lignesList = QtCore.QStringList()
       # lignesList << 'Tous' << 'RER A' << 'RER B' << 'RER C' << 'RER D' << 'RER E'
@@ -207,10 +239,15 @@ class AddRideDlg(QtGui.QDialog ):
          DebugLog("Gare '%s' inconnue"%arrivee)
          raise RuntimeError("Gare '%s' inconnue"%arrivee)
       elif len(lignesA)>1:
-         print 'plusieurs lignes'
+         selLigneDlg = SelectLine(lignesA)
+         selLigneDlg.exec_()
+         if not selLigneDlg.ligne:
+            raise RuntimeError("Aucune ligne choisie")
+         else:
+            ligne = selLigneDlg.ligne.replace(u'Métro ',u'M').replace(u'RER ',u'R')
 
       DebugLog(str(lignesA))
-      
+
       req="SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (depart, ligne)
       DebugLog(req)
       c = self.db.execute(req)
