@@ -19,8 +19,15 @@ class RideView(QtGui.QWidget):
       self.model = model
       self.connect(self.model, QtCore.SIGNAL("progress"), self.updateBar)
       self.connect(self.model, QtCore.SIGNAL("info"), self.SetInfo)
+      
       self.timer = QtCore.QTimer()
+      self.timer.setSingleShot(True)
       self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.Refresh)
+      
+      self.menuTimer = QtCore.QTimer()
+      self.menuTimer.setSingleShot(True)
+      self.connect(self.menuTimer, QtCore.SIGNAL("timeout()"), self.MenuTimeOut)
+      
       self.PrepareWidget()
 
       self.animate = QtCore.QPropertyAnimation(self.progress, "size", self)
@@ -125,15 +132,43 @@ class RideView(QtGui.QWidget):
       title.setMinimumHeight(48)
       self.font.setPointSize(18)
       title.setFont(self.font)
-      title.setStyleSheet("QPushButton { background: #fff; padding:10px; color: #194F97; text-align:left; border: none } ")
+      title.setStyleSheet("QPushButton {\
+       background: #fff;\
+       padding:10px; \
+       color: #194F97; \
+       text-align:left; \
+       border: none \
+       }")
+
+       # } \
+       # QPushButton::menu-indicator { \
+       # image: url(myindicator.png); \
+       # subcontrol-position: center; \
+       # subcontrol-origin: padding; ; \
+       
       menu = QtGui.QMenu(title)
-      refreshAction = menu.addAction('Rafraichir')
-      refreshAutoAction = menu.addAction('Rafraichissement auto')
-      refreshAutoAction.setCheckable(True)
-      removeAction = menu.addAction('Supprimer ce trajet')
-      QtCore.QObject.connect(refreshAction, QtCore.SIGNAL("triggered()"), self.Refresh)
-      QtCore.QObject.connect(refreshAutoAction, QtCore.SIGNAL("triggered()"), self.RefreshAuto)
-      QtCore.QObject.connect(removeAction, QtCore.SIGNAL("triggered()"), self.Remove)
+      self.menu = menu
+
+      refreshIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('refresh.png')))
+      self.refreshAction = menu.addAction(refreshIcon, 'Rafraichir')
+      # self.refreshAction.setIconVisibleInMenu(True)
+
+      refreshAutoIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('refreshauto.png')))
+      self.refreshAutoAction = menu.addAction(refreshAutoIcon, 'Rafraichissement auto')
+      # self.refreshAutoAction.setIconVisibleInMenu(True)
+      self.refreshAutoAction.setCheckable(True)
+
+      removeIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('remove.png')))
+      self.removeAction = menu.addAction(removeIcon, 'Supprimer ce trajet')
+      # self.removeAction.setIconVisibleInMenu(True)
+
+      menu.addSeparator()
+      wikiIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('wikipedia.png')))
+      self.wikiAction = menu.addAction(wikiIcon, u'Découvrir cette ligne sur Wikipedia')
+      # self.wikiAction.setIconVisibleInMenu(True)
+      
+      QtCore.QObject.connect(menu, QtCore.SIGNAL("aboutToShow()"), self.AboutToShow)
+      
       title.setMenu(menu)
       layoutTitle.addWidget(title)
       layoutTitle.addStretch(2)
@@ -146,6 +181,22 @@ class RideView(QtGui.QWidget):
 
       if reply == QtGui.QMessageBox.Yes:
          self.parent.RemoveView(self)
+         
+   def MenuTimeOut(self):
+      QtCore.QObject.connect(self.refreshAction, QtCore.SIGNAL("triggered()"), self.Refresh)
+      QtCore.QObject.connect(self.refreshAutoAction, QtCore.SIGNAL("triggered()"), self.RefreshAuto)
+      QtCore.QObject.connect(self.removeAction, QtCore.SIGNAL("triggered()"), self.Remove)
+      QtCore.QObject.connect(self.wikiAction, QtCore.SIGNAL("triggered()"), self.Wikipedia)
+
+   def AboutToShow(self):
+      QtCore.QObject.disconnect(self.refreshAction, QtCore.SIGNAL("triggered()"), self.Refresh)
+      QtCore.QObject.disconnect(self.refreshAutoAction, QtCore.SIGNAL("triggered()"), self.RefreshAuto)
+      QtCore.QObject.disconnect(self.removeAction, QtCore.SIGNAL("triggered()"), self.Remove)
+      QtCore.QObject.disconnect(self.wikiAction, QtCore.SIGNAL("triggered()"), self.Wikipedia)
+      self.menuTimer.start(500)
+      
+   def Wikipedia(self):
+      QtGui.QDesktopServices.openUrl( self.model.getUrl() )
 
    def Animate(self, variant):
       self.progress.setFixedHeight(variant.toSize().height())
@@ -156,13 +207,12 @@ class RideView(QtGui.QWidget):
          self.progress.hide()
 
    def Refresh(self):
+      print "refresh"
       self.Busy()
       self.parent.model.RefreshDatas(self.model.id)
 
    def RefreshAuto(self):
-      if self.timer.isActive():
-         self.timer.stop()
-      else:
+      if not self.timer.isActive():
          self.timer.setInterval(self.parent.model.ttConf.refreshRateSec()*1000)
          self.timer.start()
 
@@ -181,7 +231,7 @@ class RideView(QtGui.QWidget):
          if line.error:
             self.SetInfo('ERROR', line.error)
          else:
-            if line.train=='Aucun train pour ce trajet':
+            if line.noTrain:
                #self.SetLabel(irow, 0, '',        '#fff', color, 200, 0, self.font)
                self.SetLabel(irow, 0, line.train,        '#fff', color, 200, 0, self.font, Qt.AlignLeft|Qt.AlignVCenter, 4)
             else:
