@@ -4,7 +4,7 @@
 import os, sys, time
 from PyQt4 import QtGui, QtCore
 from PyQt4.QtCore import Qt
-from utils.DebugLog import DebugLog
+from utils.DebugLog import DebugLog, getScriptPath
 from model.TrainTrainModel import TrainTrainModel
 from view.RideView import RideView
 from view.SettingsDlg import SettingsDlg
@@ -24,6 +24,7 @@ class TrainTrainView(QtGui.QMainWindow):
       height = desktop.screenGeometry().height()
       self.setMaximumSize(QtCore.QSize(width, width))
       self.setMinimumSize(QtCore.QSize(height, width))
+      self.iconsPath = os.path.join(os.path.dirname(getScriptPath()), 'icons')
 
       try:
          self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
@@ -44,6 +45,9 @@ class TrainTrainView(QtGui.QMainWindow):
       self.CreateAppLayouts()
       self.ReInit()
 
+   def IconPath(self, str):
+      return os.path.join(self.iconsPath, str)
+      
    def ReInit(self):
       DebugLog("TrainTrainView::ReInit")
 
@@ -89,7 +93,8 @@ class TrainTrainView(QtGui.QMainWindow):
    def CreateAppLayouts(self):
       DebugLog("TrainTrainView::CreateAppLayouts")
 
-      add = QtGui.QAction(u'Ajouter un trajet', self)
+      addIcon = QtGui.QIcon(QtGui.QPixmap(self.IconPath('add48.png')))
+      add = QtGui.QAction(addIcon, u'Ajouter un trajet', self)
       add.setShortcut('Ctrl+A')
       self.connect(add, QtCore.SIGNAL('triggered()'),self.AddRide)
 
